﻿using Microsoft.SmallBasic.Library;

namespace SBAliases
{
    /// <summary>
    /// The Controls object allows you to add, move and interact with controls.
    /// </summary>
    [SmallBasicType]
    public static class _Controls
    {
        /// <summary>
        /// Gets the last Button that was clicked on the Graphics Window.
        /// </summary>
        public static Primitive LastClickedButton
        {
            get
            {
                return Controls.LastClickedButton;
            }
        }

        /// <summary>Gets the last TextBox, text was typed into.</summary>
        public static Primitive LastTypedTextBox
        {
            get
            {
                return Controls.LastTypedTextBox;
            }
        }

        /// <summary>Raises an event when any button control is clicked.</summary>
        public static event SmallBasicCallback ButtonClicked
        {
            add
            {
                Controls.ButtonClicked += value;
            }
            remove
            {
                Controls.ButtonClicked -= value;
            }
        }

        /// <summary>
        /// Raises an event when text is typed into any TextBox control.
        /// </summary>
        public static event SmallBasicCallback TextTyped
        {
            add
            {
                Controls.TextTyped += value;
            }
            remove
            {
                Controls.TextTyped -= value;
            }
        }

        /// <summary>
        /// Adds a button to the graphics window at the specified position.
        /// </summary>
        /// <param name="caption">The caption to display in the button.</param>
        /// <param name="left">The x co-ordinate of the button.</param>
        /// <param name="top">The y co-ordinate of the button.</param>
        /// <returns>
        /// The button that was just added to the Graphics Window.
        /// </returns>
        public static Primitive AddButton(Primitive caption, Primitive left, Primitive top)
        {
            return Controls.AddButton(caption, left, top);
        }

        /// <summary>Gets the current caption of the specified button.</summary>
        /// <param name="buttonName">The Button whose caption is requested.</param>
        /// <returns>The current caption of the button.</returns>
        public static Primitive GetButtonCaption(Primitive buttonName)
        {
            return Controls.GetButtonCaption(buttonName);
        }

        /// <summary>Sets the caption of the specified button.</summary>
        /// <param name="buttonName">
        /// The Button whose caption needs to be set.
        /// </param>
        /// <param name="caption">The new caption for the button.</param>
        public static void SetButtonCaption(Primitive buttonName, Primitive caption)
        {
            Controls.SetButtonCaption(buttonName, caption);
        }

        /// <summary>
        /// Adds a text input box to the graphics window at the specified position.
        /// </summary>
        /// <param name="left">The x co-ordinate of the text box.</param>
        /// <param name="top">The y co-ordinate of the text box.</param>
        /// <returns>
        /// The text box that was just added to the Graphics Window.
        /// </returns>
        public static Primitive AddTextBox(Primitive left, Primitive top)
        {
            return Controls.AddTextBox(left, top);
        }

        /// <summary>
        /// Adds a multi-line text input box to the graphics window at the specified position.
        /// </summary>
        /// <param name="left">The x co-ordinate of the text box.</param>
        /// <param name="top">The y co-ordinate of the text box.</param>
        /// <returns>
        /// The text box that was just added to the Graphics Window.
        /// </returns>
        public static Primitive AddMultiLineTextBox(Primitive left, Primitive top)
        {
            return Controls.AddMultiLineTextBox(left, top);
        }

        /// <summary>Gets the current text of the specified TextBox.</summary>
        /// <param name="textBoxName">The TextBox whose text is requested.</param>
        /// <returns>The text in the TextBox</returns>
        public static Primitive GetTextBoxText(Primitive textBoxName)
        {
            return Controls.GetTextBoxText(textBoxName);
        }

        /// <summary>Sets the text of the specified TextBox.</summary>
        /// <param name="textBoxName">
        /// The TextBox whose text needs to be set.
        /// </param>
        /// <param name="text">The new text for the TextBox.</param>
        public static void SetTextBoxText(Primitive textBoxName, Primitive text)
        {
            Controls.SetTextBoxText(textBoxName, text);
        }

        /// <summary>Removes a control from the Graphics Window.</summary>
        /// <param name="controlName">
        /// The name of the control that needs to be removed.
        /// </param>
        public static void Remove(Primitive controlName)
        {
            Controls.Remove(controlName);
        }

        /// <summary>
        /// Moves the control with the specified name to a new position.
        /// </summary>
        /// <param name="control">The name of the control to move.</param>
        /// <param name="x">The x co-ordinate of the new position.</param>
        /// <param name="y">The y co-ordinate of the new position.</param>
        public static void Move(Primitive control, Primitive x, Primitive y)
        {
            Controls.Move(control, x, y);
        }

        /// <summary>Sets the size of the control.</summary>
        /// <param name="control">The name of the control to be resized.</param>
        /// <param name="width">The width of the control.</param>
        /// <param name="height">The height of the control.</param>
        public static void SetSize(Primitive control, Primitive width, Primitive height)
        {
            Controls.SetSize(control, width, height);
        }

        /// <summary>Hides an already added control.</summary>
        /// <param name="controlName">The name of the control.</param>
        public static void HideControl(Primitive controlName)
        {
            Controls.HideControl(controlName);
        }

        /// <summary>Shows a previously hidden control.</summary>
        /// <param name="controlName">The name of the control.</param>
        public static void ShowControl(Primitive controlName)
        {
            Controls.ShowControl(controlName);
        }
    }
}
