﻿using Microsoft.SmallBasic.Library;

namespace SBAliases
{
    /// <summary>
    /// The File object provides methods to access, read and write information from and to a file on disk.  Using this object, it is possible to save and open settings across multiple sessions of your program.
    /// </summary>
    [SmallBasicType]
    public static class _File
    {
        /// <summary>
        /// <para>
        /// Gets or sets the last encountered file operation based error message.  This property is useful for finding out when some method fails to execute.
        /// </para>
        /// </summary>
        public static Primitive LastError
        {
            get
            {
                return File.LastError;
            }
            set
            {
                File.LastError = value;
            }
        }

        /// <summary>
        /// <para>
        /// Opens a file and reads the entire file's contents.  This method will be fast for small files that are less than an MB in size, but will start to slow down and will be noticeable for files greater than 10MB.
        /// </para>
        /// </summary>
        /// <param name="filePath">
        /// <para>
        /// The full path of the file to read.  An example of a full path will be c:\temp\settings.data.
        /// </para>
        /// </param>
        /// <returns>The entire contents of the file.</returns>
        public static Primitive ReadContents(Primitive filePath)
        {
            return File.ReadContents(filePath);
        }

        /// <summary>
        /// <para>
        /// Opens a file and writes the specified contents into it, replacing the original contents with the new content.
        /// </para>
        /// </summary>
        /// <param name="filePath">
        /// <para>
        /// The full path of the file to write to.  An example of a full path will be c:\temp\settings.data.
        /// </para>
        /// </param>
        /// <param name="contents">
        /// The contents to write into the specified file.
        /// </param>
        /// <returns>
        /// <para>
        /// If the operation was successful, this will return "SUCCESS".  Otherwise, it will return "FAILED".
        /// </para>
        /// </returns>
        public static Primitive WriteContents(Primitive filePath, Primitive contents)
        {
            return File.WriteContents(filePath, contents);
        }

        /// <summary>
        /// Opens the specified file and reads the contents at the specified line number.
        /// </summary>
        /// <param name="filePath">
        /// <para>
        /// The full path of the file to read from.  An example of a full path will be c:\temp\settings.data.
        /// </para>
        /// </param>
        /// <param name="lineNumber">The line number of the text to be read.</param>
        /// <returns>The text at the specified line of the specified file.</returns>
        public static Primitive ReadLine(Primitive filePath, Primitive lineNumber)
        {
            return File.ReadLine(filePath, lineNumber);
        }

        /// <summary>
        /// <para>
        /// Opens the specified file and write the contents at the specified line number.
        /// </para>
        /// <para>
        /// This operation will overwrite any existing content at the specified line.
        /// </para>
        /// </summary>
        /// <param name="filePath">
        /// <para>
        /// The full path of the file to read from.  An example of a full path will be c:\temp\settings.data.
        /// </para>
        /// </param>
        /// <param name="lineNumber">The line number of the text to write.</param>
        /// <param name="contents">
        /// <para>
        /// The contents to write at the specified line of the specified file.
        /// </para>
        /// </param>
        /// <returns>
        /// <para>
        /// If the operation was successful, this will return "SUCCESS".  Otherwise, it will return "FAILED".
        /// </para>
        /// </returns>
        public static Primitive WriteLine(Primitive filePath, Primitive lineNumber, Primitive contents)
        {
            return File.WriteLine(filePath, lineNumber, contents);
        }

        /// <summary>
        /// <para>
        /// Opens the specified file and inserts the contents at the specified line number.
        /// </para>
        /// <para>
        /// This operation will not overwrite any existing content at the specified line.
        /// </para>
        /// </summary>
        /// <param name="filePath">
        /// <para>
        /// The full path of the file to read from.  An example of a full path will be c:\temp\settings.data.
        /// </para>
        /// </param>
        /// <param name="lineNumber">The line number of the text to insert.</param>
        /// <param name="contents">The contents to insert into the file.</param>
        /// <returns>
        /// <para>
        /// If the operation was successful, this will return "SUCCESS".  Otherwise, it will return "FAILED".
        /// </para>
        /// </returns>
        public static Primitive InsertLine(
          Primitive filePath,
          Primitive lineNumber,
          Primitive contents)
        {
            return File.InsertLine(filePath, lineNumber, contents);
        }

        /// <summary>
        /// <para>
        /// Opens the specified file and appends the contents to the end of the file.
        /// </para>
        /// </summary>
        /// <param name="filePath">
        /// <para>
        /// The full path of the file to read from.  An example of a full path will be c:\temp\settings.data.
        /// </para>
        /// </param>
        /// <param name="contents">
        /// The contents to append to the end of the file.
        /// </param>
        /// <returns>
        /// <para>
        /// If the operation was successful, this will return "SUCCESS".  Otherwise, it will return "FAILED".
        /// </para>
        /// </returns>
        public static Primitive AppendContents(Primitive filePath, Primitive contents)
        {
            return File.AppendContents(filePath, contents);
        }

        /// <summary>
        /// <para>
        /// Copies the specified source file to the destination file path.  If the destination points to a location that doesn't exist, the method will attempt to create it automatically.
        /// </para>
        /// <para>
        /// Existing files will be overwritten.  It is always best to check if the destination file exists if you don't want to overwrite existing files.
        /// </para>
        /// </summary>
        /// <param name="sourceFilePath">
        /// <para>
        /// The full path of the file that needs to be copied.  An example of a full path will be c:\temp\settings.data.
        /// </para>
        /// </param>
        /// <param name="destinationFilePath">
        /// The destination location or the file path.
        /// </param>
        /// <returns>
        /// If the operation was successful, this will return "SUCCESS".  Otherwise, it will return "FAILED".
        /// </returns>
        public static Primitive CopyFile(Primitive sourceFilePath, Primitive destinationFilePath)
        {
            return File.CopyFile(sourceFilePath, destinationFilePath);
        }

        /// <summary>Deletes the specified file.</summary>
        /// <param name="filePath">
        /// <para>
        /// The destination location or the file path.  An example of a full path will be
        /// c:\temp\settings.data.
        /// </para>
        /// </param>
        /// <returns>
        /// If the operation was successful, this will return "SUCCESS".  Otherwise, it will return "FAILED".
        /// </returns>
        public static Primitive DeleteFile(Primitive filePath)
        {
            return File.DeleteFile(filePath);
        }

        /// <summary>Creates the specified directory.</summary>
        /// <param name="directoryPath">
        /// The full path of the directory to be created.
        /// </param>
        /// <returns>
        /// If the operation was successful, this will return "SUCCESS".  Otherwise, it will return "FAILED".
        /// </returns>
        public static Primitive CreateDirectory(Primitive directoryPath)
        {
            return File.CreateDirectory(directoryPath);
        }

        /// <summary>Deletes the specified directory.</summary>
        /// <param name="directoryPath">
        /// The full path of the directory to be deleted.
        /// </param>
        /// <returns>
        /// If the operation was successful, this will return "SUCCESS".  Otherwise, it will return "FAILED".
        /// </returns>
        public static Primitive DeleteDirectory(Primitive directoryPath)
        {
            return File.DeleteDirectory(directoryPath);
        }

        /// <summary>
        /// Gets the path of all the files in the specified directory path.
        /// </summary>
        /// <param name="directoryPath">The directory to look for files.</param>
        /// <returns>
        /// If the operation was successful, this will return the files as an array.  Otherwise, it will return "FAILED".
        /// </returns>
        public static Primitive GetFiles(Primitive directoryPath)
        {
            return File.GetFiles(directoryPath);
        }

        /// <summary>
        /// Gets the path of all the directories in the specified directory path.
        /// </summary>
        /// <param name="directoryPath">
        /// The directory to look for subdirectories.
        /// </param>
        /// <returns>
        /// If the operation was successful, this will return the list of directories as an array.  Otherwise, it will return "FAILED".
        /// </returns>
        public static Primitive GetDirectories(Primitive directoryPath)
        {
            return File.GetDirectories(directoryPath);
        }

        /// <summary>
        /// <para>
        /// Creates a new temporary file in a temporary directory and returns the
        /// full file path.
        /// </para>
        /// </summary>
        /// <returns>The full file path of the temporary file.</returns>
        public static Primitive GetTemporaryFilePath()
        {
            return File.GetTemporaryFilePath();
        }

        /// <summary>
        /// <para>
        /// Gets the full path of the settings file for this program.  The settings file name is based on the program's name and is present in the same location as the program.
        /// </para>
        /// </summary>
        /// <returns>
        /// The full path of the settings file specific for this program.
        /// </returns>
        public static Primitive GetSettingsFilePath()
        {
            return File.GetSettingsFilePath();
        }
    }
}
