﻿using Microsoft.SmallBasic.Library;

namespace SBAliases
{
    /// <summary>
    /// The Sound object provides operations that allow the playback of sounds.  Some sample sounds are provided along with the library.
    /// </summary>
    [SmallBasicType]
    public static class _Sound
    {
        /// <summary>Plays the Click Sound.</summary>
        public static void PlayClick()
        {
            Sound.PlayClick();
        }

        /// <summary>Plays the Click Sound and waits for it to finish.</summary>
        public static void PlayClickAndWait()
        {
            Sound.PlayClickAndWait();
        }

        /// <summary>Plays the Chime Sound.</summary>
        public static void PlayChime()
        {
            Sound.PlayChime();
        }

        /// <summary>Plays the Chime Sound and waits for it to finish.</summary>
        public static void PlayChimeAndWait()
        {
            Sound.PlayChimeAndWait();
        }

        /// <summary>Plays the Chimes Sound.</summary>
        public static void PlayChimes()
        {
            Sound.PlayChimes();
        }

        /// <summary>Plays the Chimes Sound and waits for it to finish.</summary>
        public static void PlayChimesAndWait()
        {
            Sound.PlayChimesAndWait();
        }

        /// <summary>Plays the Bell Ring Sound.</summary>
        public static void PlayBellRing()
        {
            Sound.PlayBellRing();
        }

        /// <summary>Plays the Bell Ring Sound and waits for it to finish.</summary>
        public static void PlayBellRingAndWait()
        {
            Sound.PlayBellRingAndWait();
        }

        /// <summary>Plays musical notes.</summary>
        /// <param name="notes">
        /// A set of musical notes to play.  The format is a subset of the Music Macro Language supported by QBasic.
        /// </param>
        /// <example>
        /// <code>
        /// Sound.PlayMusic("O5 C8 C8 G8 G8 A8 A8 G4 F8 F8 E8 E8 D8 D8 C4")
        /// </code>
        /// </example>
        public static void PlayMusic(Primitive notes)
        {
            Sound.PlayMusic(notes);
        }

        /// <summary>
        /// <para>
        /// Plays an audio file.  This could be an mp3 or wav or wma file.  Other file formats may or may not play depending on the audio codecs installed on the user's computer.
        /// </para>
        /// <para>
        /// If the file was already paused, this operation will resume from the position where the playback was paused.
        /// </para>
        /// </summary>
        /// <param name="filePath">
        /// The path for the audio file.  This could either be a local file (e.g.: c:\music\track1.mp3) or a file on the network (e.g.: http://contoso.com/track01.wma).
        /// </param>
        public static void Play(Primitive filePath)
        {
            Sound.Play(filePath);
        }

        /// <summary>
        /// <para>
        /// Plays an audio file and waits until it is finished playing.  This could be an mp3 or wav or wma file. Other file formats may or may not play depending on the audio codecs installed on the user's computer.
        /// </para>
        /// <para>
        /// If the file was already paused, this operation will resume from the position where the playback was paused.
        /// </para>
        /// </summary>
        /// <param name="filePath">
        /// The path for the audio file.  This could either be a local file (e.g.: c:\music\track1.mp3) or a file on the network (e.g.: http://contoso.com/track01.wma).
        /// </param>
        public static void PlayAndWait(Primitive filePath)
        {
            Sound.PlayAndWait(filePath);
        }

        /// <summary>
        /// Pauses playback of an audio file.  If the file was not already playing, this operation will not do anything.
        /// </summary>
        /// <param name="filePath">
        /// The path for the audio file.  This could either be a local file (e.g.: c:\music\track1.mp3) or a file on the network (e.g.: http://contoso.com/track01.wma).
        /// </param>
        public static void Pause(Primitive filePath)
        {
            Sound.Pause(filePath);
        }

        /// <summary>
        /// Stops playback of an audio file.  If the file was not already playing, this operation will not do anything.
        /// </summary>
        /// <param name="filePath">
        /// The path for the audio file.  This could either be a local file (e.g.: c:\music\track1.mp3) or a file on the network (e.g.: http://contoso.com/track01.wma).
        /// </param>
        public static void Stop(Primitive filePath)
        {
            Sound.Stop(filePath);
        }
    }
}
