﻿using Microsoft.SmallBasic.Library;

namespace SBAliases
{
    /// <summary>
    /// The Timer object provides an easy way for doing something repeatedly with a constant interval between.
    /// </summary>
    [SmallBasicType]
    public static class _Timer
    {
        /// <summary>
        /// Gets or sets the interval (in milliseconds) specifying how often the timer should raise the Tick event.  This value can range from 10 to 100000000
        /// </summary>
        public static Primitive Interval
        {
            get
            {
                return Timer.Interval;
            }
            set
            {
                Timer.Interval = value;
            }
        }

        /// <summary>Raises an event when the timer ticks.</summary>
        public static event SmallBasicCallback Tick
        {
            add
            {
                Timer.Tick += value;
            }
            remove
            {
                Timer.Tick -= value;
            }
        }

        /// <summary>Pauses the timer.  Tick events will not be raised.</summary>
        public static void Pause()
        {
            Timer.Pause();
        }

        /// <summary>
        /// Resumes the timer from a paused state.  Tick events will now be raised.
        /// </summary>
        public static void Resume()
        {
            Timer.Resume();
        }
    }
}
