﻿using Microsoft.SmallBasic.Library;

namespace SBAliases
{
    /// <summary>
    /// The Turtle provides Logo-like functionality to draw shapes by manipulating the properties of a pen and drawing primitives.
    /// </summary>
    [SmallBasicType]
    public static class _Turtle
    {
        /// <summary>
        /// Specifies how fast the turtle should move.  Valid values are 1 to 10.  If Speed is set to 10, the turtle moves and rotates instantly.
        /// </summary>
        public static Primitive Speed
        {
            get
            {
                return Turtle.Speed;
            }
            set
            {
                Turtle.Speed = value;
            }
        }

        /// <summary>
        /// Gets or sets the current angle of the turtle.  While setting, this will turn the turtle instantly to the new angle.
        /// </summary>
        public static Primitive Angle
        {
            get
            {
                return Turtle.Angle;
            }
            set
            {
                Turtle.Angle = value;
            }
        }

        /// <summary>
        /// Gets or sets the X location of the Turtle.  While setting, this will move the turtle instantly to the new location.
        /// </summary>
        public static Primitive X
        {
            get
            {
                return Turtle.X;
            }
            set
            {
                Turtle.X = value;
            }
        }

        /// <summary>
        /// Gets or sets the Y location of the Turtle.  While setting, this will move the turtle instantly to the new location.
        /// </summary>
        public static Primitive Y
        {
            get
            {
                return Turtle.Y;
            }
            set
            {
                Turtle.Y = value;
            }
        }

        /// <summary>Shows the Turtle to enable interactions with it.</summary>
        public static void Show()
        {
            Turtle.Show();
        }

        /// <summary>Hides the Turtle and disables interactions with it.</summary>
        public static void Hide()
        {
            Turtle.Hide();
        }

        /// <summary>
        /// Sets the pen down to enable the turtle to draw as it moves.
        /// </summary>
        public static void PenDown()
        {
            Turtle.PenDown();
        }

        /// <summary>Lifts the pen up to stop drawing as the turtle moves.</summary>
        public static void PenUp()
        {
            Turtle.PenUp();
        }

        /// <summary>
        /// Moves the turtle to a specified distance.  If the pen is down, it will draw a line as it moves.
        /// </summary>
        /// <param name="distance">The distance to move the turtle.</param>
        public static void Move(Primitive distance)
        {
            Turtle.Move(distance);
        }

        /// <summary>
        /// Turns and moves the turtle to the specified location.  If the pen is down, it will draw a line as it moves.
        /// </summary>
        /// <param name="x">The x co-ordinate of the destination point.</param>
        /// <param name="y">The y co-ordinate of the destination point.</param>
        public static void MoveTo(Primitive x, Primitive y)
        {
            Turtle.MoveTo(x, y);
        }

        /// <summary>
        /// Turns the turtle by the specified angle.  Angle is in degrees and can be either positive or negative.  If the angle is positive, the turtle turns to its right.  If it is negative, the turtle turns to its left.
        /// </summary>
        /// <param name="angle">The angle to turn the turtle.</param>
        public static void Turn(Primitive angle)
        {
            Turtle.Turn(angle);
        }

        /// <summary>Turns the turtle 90 degrees to the right.</summary>
        public static void TurnRight()
        {
            Turtle.TurnRight();
        }

        /// <summary>Turns the turtle 90 degrees to the left.</summary>
        public static void TurnLeft()
        {
            Turtle.TurnLeft();
        }
    }
}
